<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>Inicia l&apos;aplicació amb el camí del fitxer de la imatge com a argument per carregar la imatge.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>També podeu arrossegar i deixar anar un fitxer d&apos;imatge a la finestra.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="34"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>Cap de les operacions en aquesta aplicació alterarà els fitxers d&apos;imatge.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <source>Context menu option explanation:</source>
        <translation>Explicació de les opcions del menú contextual:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>Manté la finestra a sobre de totes les altres finestres.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>Evita que es tanqui la finestra accidentalment (com ara en fer doble clic a la finestra)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="48"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Version: %1</source>
        <translation>Versió: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Logo designed by %1</source>
        <translation>Logotip dissenyat por %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Creat amb Qt %1 (%2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Source code</source>
        <translation>Codi font</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>Contributors</source>
        <translation>Col·laboradors</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>List of contributors on GitHub</source>
        <translation>Llista de col·laboradors al GitHub</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>Gràcies a totes les persones que han col·laborat en aquest projecte.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>Translators</source>
        <translation>Traductors</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>M&apos;agradaria donar les gràcies a les persones següents per oferir-se a traduir aquesta aplicació.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="131"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1 està construït sobre les biblioteques de programari lliure següents:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="155"/>
        <source>&amp;Special Thanks</source>
        <translation>&amp;Especial agraïment</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="157"/>
        <source>&amp;Third-party Libraries</source>
        <translation>&amp;Biblioteques de tercers</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Your Rights</source>
        <translation>Els vostres drets</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>Copyright (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="95"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1 es publica sota la llicència MIT.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>Aquesta llicència atorga a les persones diverses llibertats:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="97"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>Sou lliure de fer servir %1 per a qualsevol propòsit</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>You are free to distribute %1</source>
        <translation>Sou lliure de distribuir %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="99"/>
        <source>You can study how %1 works and change it</source>
        <translation>Podeu estudiar com funciona %1 i modificar-lo</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="100"/>
        <source>You can distribute changed versions of %1</source>
        <translation>Podeu distribuir les versions modificades de %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>La llicència del MIT us garanteix aquesta llibertat. No és permès que ningú us la tregui.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="130"/>
        <source>Third-party Libraries used by %1</source>
        <translation>Biblioteques de tercers que fa servir %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="153"/>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="154"/>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="156"/>
        <source>&amp;License</source>
        <translation>&amp;Llicència</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../graphicsscene.cpp" line="102"/>
        <source>Drag image here</source>
        <translation>Arrossegueu una imatge aquí</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <source>File url list is empty</source>
        <translation type="vanished">La llista d&apos;ubicacions de fitxer és buida</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="51"/>
        <source>File is not a valid image</source>
        <translation>El fitxer no és una imatge vàlida</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="55"/>
        <location filename="../graphicsview.cpp" line="60"/>
        <location filename="../graphicsview.cpp" line="71"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>Les dades de la imatge no són vàlides o no són compatibles</translation>
    </message>
    <message>
        <source>Image data is invalid</source>
        <translation type="vanished">Les dades de la imatge no són vàlides</translation>
    </message>
    <message>
        <source>Not supported mimedata: %1</source>
        <translation type="vanished">El tipus MIME no és compatible: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>File url list is empty</source>
        <translation>La llista d&apos;ubicacions és buida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Image data is invalid</source>
        <translation>Les dades de la imatge no són vàlides</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Not supported mimedata: %1</source>
        <translation>El tipus MIME no és compatible: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Image From Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="805"/>
        <source>Failed to move file to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="806"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Copy P&amp;ixmap</source>
        <translation>Copia el &amp;mapa de píxels</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="107"/>
        <source>Copy &amp;File Path</source>
        <translation>Copia el camí del &amp;fitxer</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Properties</source>
        <translation>Propietats</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="110"/>
        <location filename="../aboutdialog.cpp" line="41"/>
        <source>Stay on top</source>
        <translation>Mantén a sobre</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <location filename="../aboutdialog.cpp" line="44"/>
        <source>Protected mode</source>
        <translation>Mode protegit</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="112"/>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>Zoom in</source>
        <translation>Amplia</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Zoom out</source>
        <translation>Redueix</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Pause/Resume Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Animation Go to Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Inverteix &amp;horitzontalment</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Fit to view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="104"/>
        <source>Fit to width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Fit long image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>&amp;Paste</source>
        <translation>&amp;Enganxa</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Toggle Checkerboard</source>
        <translation>Commuta el tauler d&apos;escacs</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Open...</source>
        <translation>&amp;Obre...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Actual size</source>
        <translation>Mida real</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Toggle maximize</source>
        <translation>Commuta la maximització</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="93"/>
        <source>Rotate right</source>
        <translation>Commuta la maximització</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="94"/>
        <source>Rotate left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="96"/>
        <source>Previous image</source>
        <translation>Imatge anterior</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Next image</source>
        <translation>Imatge següent</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Configure...</source>
        <translation>Configura...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>Mostra al navegador de fitxers</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="123"/>
        <source>Show in directory</source>
        <translation>Mostra a la carpeta</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="126"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>Metadades de la imatge</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>Origen</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>Imatge</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>Fitxer</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>Càmera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="35"/>
        <source>%1 File</source>
        <translation>Fitxer %1</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>Foto avançada</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="47"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="54"/>
        <source>Aspect ratio</source>
        <translation>Relació d&apos;aspecte</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Frame count</source>
        <translation>Núm. d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Item type</source>
        <translation>Tipus d&apos;element</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Folder path</source>
        <translation>Camí de la carpeta</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date created</source>
        <translation>Data de creació</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="72"/>
        <source>Date modified</source>
        <translation>Data de modificació</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Subject</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Rating</source>
        <translation>Valoració</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Tags</source>
        <translation>Etiquetes</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="87"/>
        <source>Comments</source>
        <translation>Comentaris</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Authors</source>
        <translation>Autors</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Date taken</source>
        <translation>Data de la foto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Program name</source>
        <translation>Nom del programa</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="100"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Horizontal resolution</source>
        <translation>Resolució horitzontal</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Vertical resolution</source>
        <translation>Resolució vertical</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Resolution unit</source>
        <translation>Unitat de resolució</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="109"/>
        <source>Colour representation</source>
        <translation>Representació del color</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera maker</source>
        <translation>Fabricant de la càmera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>Camera model</source>
        <translation>Model de la càmera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>F-stop</source>
        <translation>Relació focal</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Exposure time</source>
        <translation>Temps d&apos;exposició</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>ISO speed</source>
        <translation>Sensibilitat ISO</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Exposure bias</source>
        <translation>Compensació d&apos;exposició</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Focal length</source>
        <translation>Distància focal</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Max aperture</source>
        <translation>Obertura màxima</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Metering mode</source>
        <translation>Mode de mesura</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Subject distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>Flash mode</source>
        <translation>Mode del flaix</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="134"/>
        <source>35mm focal length</source>
        <translation>Distància focal de 35 mm</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Lens model</source>
        <translation>Model de lent</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Brightness</source>
        <translation>Brillantor</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Exposure program</source>
        <translation>Programa d&apos;exposició</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Saturation</source>
        <translation>Saturació</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>Sharpness</source>
        <translation>Nitidesa</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>White balance</source>
        <translation>Balanç de blancs</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>Digital zoom</source>
        <translation>Zoom digital</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="153"/>
        <source>EXIF version</source>
        <translation>Versió de l&apos;EXIF</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude reference</source>
        <translation>Referència de la latitud</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Latitude</source>
        <translation>Latitud</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude reference</source>
        <translation>Referència de la longitud</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Longitude</source>
        <translation>Longitud</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude reference</source>
        <translation>Referència de l&apos;altitud</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>Altitude</source>
        <translation>Altitud</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="176"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="194"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Property</source>
        <translation>Propietat</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="63"/>
        <source>Editing shortcuts for action &quot;%1&quot;:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="72"/>
        <source>Failed to set shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="73"/>
        <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Do nothing</source>
        <translation>No facis res</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="81"/>
        <source>Close the window</source>
        <translation>Tanca la finestra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="82"/>
        <source>Toggle maximize</source>
        <translation>Commuta la maximització</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="83"/>
        <source>Toggle fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="87"/>
        <source>Zoom in and out</source>
        <translation>Amplia i redueix</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="88"/>
        <source>View next or previous item</source>
        <translation>Mostra l&apos;element següent o l&apos;anterior</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="92"/>
        <source>Auto size</source>
        <translation>Mida automàtica</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="93"/>
        <source>Maximized</source>
        <translation>Maximitza</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="94"/>
        <source>Windowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="98"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="99"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="100"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="101"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>Stay on top when start-up</source>
        <translation>Mantingues a sobre a l&apos;inici</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="125"/>
        <source>Use built-in close window animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>Use light-color checkerboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>Loop the loaded gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>Auto long image mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>Limit SVG support to SVG Tiny 1.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="130"/>
        <source>Double-click behavior</source>
        <translation>Comportament del doble clic</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Mouse wheel behavior</source>
        <translation>Comportament de la roda del ratolí</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Default window size</source>
        <translation>Mida de la finestra per defecte</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../shortcutedit.cpp" line="104"/>
        <source>No shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <location filename="../shortcutedit.cpp" line="70"/>
        <source>Shortcut #%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Pineapple Pictures</source>
        <translation>Pineapple Pictures</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>List supported image format suffixes, and quit program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>File list.</source>
        <translation>Llista de fitxers.</translation>
    </message>
</context>
</TS>
